@@ -532,7 +532,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 
    curlabel = TOLABEL(EDITPART);
 
-   if (curlabel == NULL || curlabel->type != LABEL || areawin->textpos <= 0) {
+   if (curlabel == NULL || curlabel->type != LABEL) {
       Wprintf("Error:  Bad label string");
       text_mode_draw(xcDRAW_EMPTY, curlabel);
       eventmode = NORMAL_MODE;
@@ -729,7 +729,12 @@ Boolean labeltext(int keypressed, char *clientdata)
 
       setdefaultfontmarks();
       setcolormark(areawin->color);
-      if ((labelbuf = get_original_string(curlabel)) != NULL) {
+
+      if (!hasstuff) {
+	 /* Delete empty labels */
+	 standard_element_delete(NORMAL);
+      }
+      else if ((labelbuf = get_original_string(curlabel)) != NULL) {
 
 	 /* If the original label (before modification) is a pin in a	*/
 	 /* schematic/symbol with a matching symbol/schematic, and the	*/
@@ -910,7 +915,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 	          areawin->textpos++;
 	          curpos = findstringpart(areawin->textpos, &locpos, curlabel->string,
 	 		areawin->topinstance);
-	       } while (curpos->type != PARAM_END);
+	       } while (curpos && (curpos->type != PARAM_END));
 	    }
 	    break;
       }
