@@ -2218,7 +2218,7 @@ float UGetRescaleBox(XPoint *corner, XPoint *newpoints)
 
    if (!areawin->redraw_ongoing) {
       areawin->redraw_needed = True;
-      return 0.0;
+      // return 0.0;
    }
 
    if (areawin->selects == 0) return 0.0;
