@@ -778,6 +778,7 @@ short undo_one_action()
 	 snum = thisrecord->idata;
 	 thisrecord->idata = thislabel->justify;
 	 thislabel->justify = snum;
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -788,8 +789,10 @@ short undo_one_action()
 	 
 	 need_redraw = (areawin->selects > 0) ? True : False;
 	 select_previous(thisrecord);
-	 if (need_redraw)
+	 if (need_redraw) {
+	    areawin->redraw_needed = True;
 	    drawarea(areawin->area, NULL, NULL);
+	 }
 	 else
 	    draw_all_selected();
 	 break;
@@ -805,6 +808,7 @@ short undo_one_action()
 	 }
 	 else {
 	    delete_one_element(thisrecord->thisinst, egen);
+	    areawin->redraw_needed = True;
 	    drawarea(areawin->area, NULL, NULL);
 	 }
 	 break;
@@ -842,6 +846,7 @@ short undo_one_action()
 	       earc->position = erec->save.arcspecs->position;
 	       *(erec->save.arcspecs) = tmpinfo;
 	       calcarc(earc);
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    } break;
 	    case OBJINST: {
@@ -851,6 +856,7 @@ short undo_one_action()
 	       tmppt = einst->position;
 	       einst->position = erec->save.instpos;
 	       erec->save.instpos = tmppt;
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    }  break;
 	    case POLYGON: {
@@ -863,6 +869,7 @@ short undo_one_action()
 	       epoly->number = thisrecord->idata;
 	       erec->save.points = tmppts;
 	       thisrecord->idata = tmpnum;
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    } break;
 	    case SPLINE: {
@@ -874,6 +881,7 @@ short undo_one_action()
 	       free(erec->save.points);
 	       erec->save.points = tmppts;
 	       calcspline(espline);
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    } break;
 	    case PATH: {
@@ -905,6 +913,7 @@ short undo_one_action()
 			break;
 		  }
 	       }
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    }
 	 }
@@ -930,6 +939,7 @@ short undo_one_action()
 
 	 /* Revert selection to previously selected */
 	 select_previous(thisrecord);
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 draw_all_selected();
 	 break;
@@ -960,6 +970,7 @@ short undo_one_action()
 	       thisspline->style = snum;
 	       break;
 	 }
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -989,6 +1000,7 @@ short undo_one_action()
 	       thisspline->color = snum;
 	       break;
 	 }
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1036,6 +1048,7 @@ short undo_one_action()
 	       thislabel->scale = fnum;
 	       break;
 	 }
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1059,12 +1072,14 @@ short undo_one_action()
 	 select_connected_pins();
 	 placeselects(-(delta->x), -(delta->y), NULL);
 	 reset_cycles();
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 draw_all_selected();
 	 break;
 
        case XCF_Reorder:
 	 reorder_selection(thisrecord);
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1184,6 +1199,7 @@ short redo_one_action()
 	 thisrecord->undodata = (char *)thisobj;
 	 thisrecord->idata = (int)DRAW;
 	 unselect_all();
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1202,6 +1218,7 @@ short redo_one_action()
 	 snum = thisrecord->idata;
 	 thisrecord->idata = thislabel->justify;
 	 thislabel->justify = snum;
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1251,6 +1268,7 @@ short redo_one_action()
       case XCF_Spline: case XCF_Dot: case XCF_Graphic: case XCF_Join:
 	 egen = (genericptr)thisrecord->undodata;
 	 undelete_one_element(thisrecord->thisinst, egen);
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1279,6 +1297,7 @@ short redo_one_action()
 	       tmppt = einst->position;
 	       einst->position = erec->save.instpos;
 	       erec->save.instpos = tmppt;
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    }  break;
 	    case ARC: {
@@ -1296,6 +1315,7 @@ short redo_one_action()
 	       earc->position = erec->save.arcspecs->position;
 	       *(erec->save.arcspecs) = tmpinfo;
 	       calcarc(earc);
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    } break;
 	    case POLYGON: {
@@ -1308,6 +1328,7 @@ short redo_one_action()
 	       epoly->number = thisrecord->idata;
 	       erec->save.points = tmppts;
 	       thisrecord->idata = tmpnum;
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    } break;
 	    case SPLINE: {
@@ -1319,6 +1340,7 @@ short redo_one_action()
 	       free(erec->save.points);
 	       erec->save.points = tmppts;
 	       calcspline(espline);
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    } break;
 	    case PATH: {
@@ -1350,6 +1372,7 @@ short redo_one_action()
 			break;
 		  }
 	       }
+	       areawin->redraw_needed = True;
 	       drawarea(areawin->area, NULL, NULL);
 	    }
 	 }
@@ -1391,6 +1414,7 @@ short redo_one_action()
 	       thisspline->style = snum;
 	       break;
 	 }
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1420,6 +1444,7 @@ short redo_one_action()
 	       thisspline->color = snum;
 	       break;
 	 }
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1467,6 +1492,7 @@ short redo_one_action()
 	       thislabel->scale = fnum;
 	       break;
 	 }
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
@@ -1480,11 +1506,13 @@ short redo_one_action()
 	 select_connected_pins();
 	 placeselects(delta->x, delta->y, NULL);
 	 reset_cycles();
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
       case XCF_Reorder:
 	 reorder_selection(thisrecord);
+	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
 
